import QtQuick 2.0
import com.embeddeduse.keynav 1.0

FocusScope {
    id: root

    signal released()

    KeyNav.backtabDown: root
    KeyNav.tabDown: root

    Keys.onBacktabPressed: {
        root.KeyNav.backtabUp.doBacktab()
        event.accepted = true
    }

    Keys.onTabPressed: {
        root.KeyNav.tabUp.doTab()
        event.accepted = true
    }

    Keys.onPressed: {
        if (event.key === Qt.Key_Return) {
            root.state = "pressed"
            event.accepted = true
        }
    }

    Keys.onReleased: {
        if (event.key === Qt.Key_Return) {
            root.state = "focused"
            root.released()
            event.accepted = true
        }
    }

    MouseArea
    {
        id: mouseArea
        anchors.fill: parent

        onPressed: {
            root.doMousePress()
            root.state = "pressed"
            mouse.accepted = true
        }

        onReleased: {
            if (root.activeFocus) {
                root.state = "focused"
                root.released()
            }
            mouse.accepted = true
        }
    }

    BorderImage
    {
        id: cursorShape
        anchors.fill: parent
        border { left: 8; top: 8; right: 8; bottom: 8 }
        source: "no_cursor.png"
    }

    states: [
        State {
            name: ""
            when: !root.activeFocus
            PropertyChanges { target: cursorShape; source: "no_cursor.png" }
        },
        State {
            name: "focused"
            when: root.activeFocus
            PropertyChanges { target: cursorShape; source: "focused_cursor.png" }
        },
        State {
            name: "pressed"
            PropertyChanges { target: cursorShape; source: "pressed_cursor.png" }
        }
    ]

}
